#include "msgClient.hh"

using namespace std;

msgClient::msgClient() {}

msgClient::~msgClient() {}

bool msgClient::connect(const std::string& name, const std::string& server, unsigned int port) {
	bool connected = client.connect(server, port);
	if(connected) {
		this->client.subscribe(name);
		this->name = name;
		this->s_name = server;
		this->s_port = port;
	}
	return connected;
}

void msgClient::disconnect() {
	client.disconnect();
}

bool msgClient::isConnected() {
	return client.isConnected();
} 

bool msgClient::sendMessage(const std::string& dest, const std::string& content) {
	if(this->isConnected()) {
		message msg;
		msg.encode(dest.c_str(), content.c_str());
		return client.send(msg);
	}
	return false;
}

bool msgClient::sendBroadcastMessage(const std::string& content) {
	if(this->isConnected()) {
		message msg;
		msg.encode("BROADCAST_ALL", content.c_str());
		return client.send(msg);
	}
	return false;
}

bool msgClient::isMessageWaiting() {
	if(this->isConnected()) {
		return client.checkReadSocket(false);
	}
	return false;
}

pair<string, string> msgClient::getMessage() {
	if(this->isConnected()) {
		std::pair<iclient::received, message> msg = client.receive();
		if(msg.first==iclient::STAT_ERR){
			return make_pair("", STATUS_DISCONNECTED);
		}else if(msg.first==iclient::STAT_RECV){
			return make_pair(msg.second.getStringHead(), msg.second.getStringBody()); 
		}
	}
	return make_pair("", STATUS_EMPTY);
}

pair<string, string> msgClient::getBlockingMessage() {
	if(this->isConnected()) {
		if(client.checkReadSocket(true)) return this->getMessage();
	}
	return make_pair("", STATUS_DISCONNECTED);
}

